@@ -2,7 +2,7 @@ use super::{
     elements::{Line, Text},
     text_style::TextStyle,
 };
-use std::mem;
+use std::{fmt, mem};
 use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
 
 /// A weighted line of text.
@@ -30,12 +30,6 @@ impl WeightedLine {
     pub(crate) fn font_size(&self) -> u8 {
         self.font_size
     }
-
-    /// Get an iterator to the underlying text chunks.
-    #[cfg(test)]
-    pub(crate) fn iter_texts(&self) -> impl Iterator<Item = &WeightedText> {
-        self.text.iter()
-    }
 }
 
 impl From<Line> for WeightedLine {
@@ -90,7 +84,7 @@ struct CharAccumulator {
 }
 
 /// A piece of weighted text.
-#[derive(Clone, Debug, PartialEq, Eq)]
+#[derive(Clone, PartialEq, Eq)]
 pub(crate) struct WeightedText {
     text: Text,
     accumulators: Vec<CharAccumulator>,
@@ -131,6 +125,12 @@ impl From<Text> for WeightedText {
     }
 }
 
+impl fmt::Debug for WeightedText {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.debug_struct("WeightedText").field("text", &self.text).finish()
+    }
+}
+
 /// An iterator over the chunks in a [WeightedLine].
 pub(crate) struct SplitTextIter<'a> {
     texts: &'a [WeightedText],
